# Table of Contents

- [importing-and-exporting-transformations-via-excel-file](<./importing-and-exporting-transformations-via-excel-file.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
  - [Table of Contents](<./SAP-LeanIX/Table-of-Contents.md>)
- [Importing and Exporting Transformations via Excel File](<./Importing-and-Exporting-Transformations-via-Excel-File.md>)
  - [Introduction](<./Importing-and-Exporting-Transformations-via-Excel-File/Introduction.md>)
  - [Permissions](<./Importing-and-Exporting-Transformations-via-Excel-File/Permissions.md>)
  - [Exporting Transformation Items Via Excel File](<./Importing-and-Exporting-Transformations-via-Excel-File/Exporting-Transformation-Items-Via-Excel-File.md>)
  - [Importing Transformation Items Via Excel File](<./Importing-and-Exporting-Transformations-via-Excel-File/Importing-Transformation-Items-Via-Excel-File.md>)
  - [Updating the Data in the Spreadsheet](<./Importing-and-Exporting-Transformations-via-Excel-File/Updating-the-Data-in-the-Spreadsheet.md>)
  - [Uploading File](<./Importing-and-Exporting-Transformations-via-Excel-File/Uploading-File.md>)
  - [Reviewing Upload Status and Error Handling](<./Importing-and-Exporting-Transformations-via-Excel-File/Reviewing-Upload-Status-and-Error-Handling.md>)
  - [Was this page helpful?](<./Importing-and-Exporting-Transformations-via-Excel-File/Was-this-page-helpful.md>)
